@@ -32,12 +32,13 @@ class AlphaBacktest:
         else:
             self._principal=config["principal"]
             self._net_value_list=[self._principal]
+        self.position_volume=defaultdict(int)
         self._is_config=True
     def run(self,position_details:pd.DataFrame,open_price:Dict[str,pd.DataFrame],close_price:Dict[str,pd.DataFrame],vwap_price:Dict[str,pd.DataFrame])->List[float]:
         """
         if just want to use close_price,you can input close_price into vwap_price
         """
-        self.position_volume=defaultdict(int)
+        
         
         for date in tqdm(position_details):
             stock_list=set(position_details[date].values.tolist())
@@ -46,16 +47,16 @@ class AlphaBacktest:
             vwap_df=vwap_price[date].to_dict()
             hold_num=len(stock_list)
             average_money=self._net_value_list[-1]/hold_num
-            for stock in self.position_volume:
+            for stock in list(self.position_volume.keys()):
                 
-                v_p=vwap_df[date]
+                v_p=vwap_df[stock]
                 if stock not in stock_list:
                     self._principal+=self.position_volume[stock]*v_p*(1-self._sell_cost_fee)
                     del self.position_volume[stock]
                 
             for stock in stock_list:
                 if stock not in self.position_volume:
-                    v_p=vwap_df[date]
+                    v_p=vwap_df[stock]
                     buy_stock_num=(average_money/v_p)//100*100
                     self.position_volume[stock]+=buy_stock_num
                     self._principal-=buy_stock_num*v_p*(1+self._buy_cost_fee)
